PROGRAM_NAME='dCS - Rossini v100'
(***********************************************************)
(*                                                         *)
(* Copy Right Message                                      *)
(* All software remains the property of Quality Concepts   *)
(* until paid for in full.                                 *)

(* Copyright (c) Quality Concepts (U.K.) Ltd. 2015.        *)
(* All Rights Reserved.                                    *)
(* This source code is provided subject to the condition   *)
(* that it shall not, by way of trade or otherwise, be     *)
(* lent, resold, hired out, or otherwise circulated. Nor   *)
(* shall it be copied, altered, modified, or amended       *)
(* without the authors prior consent and permission.       *)
(*                                                         *)
(* For further details please contact :                    *)
(* Quality Concepts (U.K.) Ltd                             *)
(* 6 St. Marys Cottages, St. Mary Hoo                      *)
(* Rochester, Kent. ME3 8RB.                               *)
(* Telephone: 01634-270038                                 *)
(* Fax:       01634-270177                                 *)
(*                                                         *)
(* Programmer - Mike Page      - Mobile:07889-308275       *)
(* MikePageQCUK@aol.com        - AMX Certified Programmer  *)
(*                                                         *)

(***********************************************************)
(*  FILE_LAST_MODIFIED_ON: 10/24/2015  AT: 09:00:25        *)
(***********************************************************)
(* System Type : NetLinx Module Test                       *)
(***********************************************************)
(* REV HISTORY:                                            *)
(***********************************************************)
(*
v1.00 24/10/2015 - MFP - Original Outline
*)
(***********************************************************)
(*          DEVICE NUMBER DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_DEVICE

// Real Devices
dvRossini									=				 5001:2:0 // RS232_2 - dCS Rossini
																						// RS232 3 wire Only Pins 2-2, 3-3 & 5-5 Female to Female

dviPad										=				11001:5:0 // iPad for Test (N.B. Port 5)

// Virtual Devices
vdvRossini								=				33100:1:0 // Virtual Rossini
vdvPanel									=				33200:1:0 // Virtual iPad

// Test and Configuration
dvDebug										=					  0:0:0 // For Data to processor Master

(***********************************************************)
(*               CONSTANT DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_CONSTANT

(***********************************************************)
(*              DATA TYPE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_TYPE

(***********************************************************)
(*               VARIABLE DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_VARIABLE

// Debug
INTEGER iDebugFlag			=	1

CHAR chrProcIPAddress[15]
CHAR chriPadIPAddress[15]

IP_ADDRESS_STRUCT MyIPAddress (* .Flags *)
(* .HostName *)
(* .IPAddress *)
(* .SubnetMask *)
(* .Gateway *)

// Online Status
INTEGER idCSRossininState

// Global Use
INTEGER iFunc
CHAR chrdCSResponseString[35]

// Unit ID - Future - Not used at this time
INTEGER iUnitID = 1

INTEGER iTransportButs[]=
	{
	1,2,3,4,5,6,7,8
	}

// 9 Power Toggle

INTEGER iNumberButs[]=
	{
	10,11,12,13,14,15,16,17,18,19
	}

INTEGER iMenuButs[]=
	{
	20,21,22,23,24,25,26,27,28,29,
	30,31,32,33,34,35,36,37,38,39,
	40,41,42,43,44,45,46,47,48,49
	}

// Mute Toggle
INTEGER iMute 	

INTEGER iPowerState
INTEGER iPowerButs[] = 
	{
	27,28
	}

INTEGER iInputState
INTEGER iInputButs[]=
	{
	30,31,32,33,34,35,36,327,38,39
	}

// 44 - Help
INTEGER iHelpBut = 44

// 45 - Status
INTEGER iStatusBut = 45

// Sync
INTEGER iSyncButs[]=
	{
	50,51,52,53,54,55,56,57,58
	}

// Gain
INTEGER iGainButs[]=
	{
	60,61
	}

// Phase
INTEGER iPhaseButs[]=
	{
	70,71
	}

// Filter
INTEGER iFilterButs[]=
	{
	80,81,82,83,84,85,86,87,88
	}

// Volume
INTEGER iVolumeLevel = 40 	// 0-80 (Invert for the Unit -80 to 0 Highest)
CHAR chrVolumeLevel[5]   		// in ASCII
INTEGER iVolButs[]=
	{
	141,142,143
	}

// Balance
INTEGER iBalance  = 7 	// 0-13 (-6 to 0 to +6)
CHAR chrBalance   			// in ASCII
INTEGER iBalButs[]=
	{
	147,148
	}

(***********************************************************)
(*               LATCHING DEFINITIONS GO BELOW             *)
(***********************************************************)
DEFINE_LATCHING

(***********************************************************)
(*       MUTUALLY EXCLUSIVE DEFINITIONS GO BELOW           *)
(***********************************************************)
DEFINE_MUTUALLY_EXCLUSIVE

// Transport 1-8
([vdvPanel,1]..[vdvPanel,8])
// Power Toggle 9
// Numbers 10-19
([vdvPanel,11]..[vdvPanel,19])
// 26 Mute Toggle
// Power
([vdvPanel,27],[vdvPanel,28])
// Inputs
([vdvPanel,30]..[vdvPanel,39])

// 44 Help
// 45 Status

// Sync
([vdvPanel,50],[vdvPanel,59])
// Gain
([vdvPanel,60],[vdvPanel,61])
// Phase
([vdvPanel,70],[vdvPanel,71])
// Filter
([vdvPanel,80]..[vdvPanel,86])

(***********************************************************)
(*        SUBROUTINE/FUNCTION DEFINITIONS GO BELOW         *)
(***********************************************************)
(* EXAMPLE: DEFINE_FUNCTION <RETURN_TYPE> <NAME> (<PARAMETERS>) *)
(* EXAMPLE: DEFINE_CALL '<NAME>' (<PARAMETERS>) *)

DEFINE_FUNCTION fnShowText (DEV dvPnl, INTEGER nTextAddress, CHAR cText[] )
	{
	SEND_COMMAND dvPnl,"'^TXT-',ITOA( nTextAddress ),',0,',cText"
	}

DEFINE_FUNCTION fnConfigPanel ()
	{
	IF(iDebugFlag) SEND_STRING dvDebug,"'fn - Display Configuration'"
	CANCEL_WAIT 'StartUp2'
	// System 0:0:0
	GET_IP_ADDRESS(dvDebug,MyIPAddress)
	chrProcIPAddress = MyIPAddress.IPAddress
	SELECT
		{
		ACTIVE(MyIPAddress.IPADDRESS = '192.168.1.21') : // Default
			{
			SET_SYSTEM_NUMBER (1)
			fnShowText (vdvPanel, 197, "'System: ',chrProcIPAddress")
			}
		}
	WAIT 20 'StartUp2'
		{
		// iPad Panel
		GET_IP_ADDRESS(dviPad,MyIPAddress)
		chriPadIPAddress = MyIPAddress.IPAddress
		fnShowText (dviPad, 198, "'Panel: ',chriPadIPAddress")
		SEND_COMMAND vdvPanel,"'PAGE-Logo Page'"
		SEND_LEVEL vdvPanel,1,iVolumeLevel
		SEND_LEVEL vdvPanel,2,iBalance
		}
	}

(***********************************************************)
(*                STARTUP CODE GOES BELOW                  *)
(***********************************************************)
DEFINE_START


(***********************************************************)
(*                 ADD MODULES GOES BELOW                  *)
(***********************************************************)

DEFINE_MODULE 'dCS Rossini Control Comm' dCSMdl (vdvRossini, dvRossini, iUnitID)
// SEND_COMMAND vdvRossini,"'Help'"						// Help Information
// SEND_COMMAND vdvRossini,"'Power-n'"				// n = 0:Off 1:On 2:Power Off
// SEND_COMMAND vdvRossini,"'Input-n'" 				// n = 0:AES1 1:AES2 2:AES12 3:SPDIF1 4:SPDIF2 5:TOSLINK 6:Network 7:USB1 8:Mechanisim
// SEND_COMMAND vdvRossini,"'Mute-n'"  				// n = 0:UnMute 1:Mute
// SEND_COMMAND vdvRossini,"'Phase-n'"  			// n = 0:Normal 1:Invert
// SEND_COMMAND vdvRossini,"'Gain-n'"  				// n = 0:2CV 1:6V
// SEND_COMMAND vdvRossini,"'Sync-n'"  				// n = 0:Audio 1:Master 2:WClk1 3:WClk2 4: AutoWClk
// SEND_COMMAND vdvRossini,"'Filter-n'"  			// n = 0:- 5
// SEND_COMMAND vdvRossini,"'Transport-n'"  	// n = 1:Play 2:Stop 3:Pause 4:FF 5:FR 6:Next 7:Prev 8:Eject
// SEND_COMMAND vdvRossini,"'Volume-xx.x'"  	// x = -80.0 to 0.0
// SEND_COMMAND vdvRossini,"'Balance-xx.x'"  	// x = 6.0 to 0.0 to -6.0

(***********************************************************)
(*                THE EVENTS GO BELOW                      *)
(***********************************************************)
DEFINE_EVENT

///////////////////////////////////////////////////////////////////////////////
DATA_EVENT[dviPad]
	{
	ONLINE: 
		{
		COMBINE_DEVICES (vdvPanel, dviPad)
		SEND_STRING dvDebug,"'Panel Devices Online'"
		fnConfigPanel ()
		}
	}

DATA_EVENT[vdvRossini]
	{
	STRING : // Data from the Module
		{
		chrdCSResponseString = DATA.TEXT
		IF(iDebugFlag) SEND_STRING dvDebug,"'RX$ from the Rossini Module - ',chrdCSResponseString"
		SELECT // Play State Feedbacks 1-8
			{
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# CDPlayState = 3 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Stop State Received from Rossini'"
				ON[vdvPanel,2]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# CDPlayState = 4 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Play State Received from Rossini'"
				ON[vdvPanel,1]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# CDPlayState = 5 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Pause State Received from Rossini'"
				ON[vdvPanel,3]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# CDPlayState = 6 #'",1)) : 
				{
				SEND_STRING dvDebug,"'FFwd State Received from Rossini'"
				ON[vdvPanel,4]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# CDPlayState = 7 #'",1)) : 
				{
				SEND_STRING dvDebug,"'FRev State Received from Rossini'"
				ON[vdvPanel,5]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# CDDiscState = 0 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Eject Received from Rossini'"
				ON[vdvPanel,8]
				}
			}
		SELECT //Power States 27 & 28
			{
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Sleep = <bool> true #'",1))  : 
				{
				SEND_STRING dvDebug,"'Power OffState Received from Rossini'"
				ON[vdvPanel,28]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Sleep = <bool> false #'",1)) : 
				{
				SEND_STRING dvDebug,"'Power On State Received from Rossini'"
				ON[vdvPanel,27]
				}
			}
		SELECT // Input States 30-38
			{
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Input = <int> 0 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Input = AES1 Received from Rossini'"
				ON[vdvPanel,30]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Input = <int> 1 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Input = AES2 Received from Rossini'"
				ON[vdvPanel,31]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Input = <int> 2 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Input = AES12 Received from Rossini'"
				ON[vdvPanel,32]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Input = <int> 3 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Input = SPDIF1 Received from Rossini'"
				ON[vdvPanel,33]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Input = <int> 4 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Input = SPDIF2 Received from Rossini'"
				ON[vdvPanel,34]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Input = <int> 5 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Input = TOSLINK Received from Rossini'"
				ON[vdvPanel,35]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Input = <int> 6 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Input = Network Received from Rossini'"
				ON[vdvPanel,36]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Input = <int> 7 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Input = USB1 Received from Rossini'"
				ON[vdvPanel,37]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Input = <int> 8 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Input = Mechanism Received from Rossini'"
				ON[vdvPanel,38]
				}
			}
		SELECT // Sync States 50-54
			{
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Sync(New) = <int> 0 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Sync State Audio Received from Rossini'"
				ON[vdvPanel,50]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Sync(New) = <int> 1 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Sync State Master Received from Rossini'"
				ON[vdvPanel,51]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Sync(New) = <int> 2 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Sync State WClk1 Received from Rossini'"
				ON[vdvPanel,52]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Sync(New) = <int> 3 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Sync State WClk2 Received from Rossini'"
				ON[vdvPanel,53]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Sync(New) = <int> 4 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Sync State Auto WClk Received from Rossini'"
				ON[vdvPanel,54]
				}
			}
		SELECT // Gain States 60 & 61
			{
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Gain(New) = <int> 0 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Gain State 2V Received from Rossini'"
				ON[vdvPanel,60]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Gain(New) = <int> 1 #'",1)) : 
				{
				SEND_STRING dvDebug,"'Gain State 6V Received from Rossini'"
				ON[vdvPanel,61]
				}
			}
		SELECT // Phase States 70 & 71
			{
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Phase = <bool> false #'",1))  : 
				{
				SEND_STRING dvDebug,"'Phase State Normal Received from Rossini'"
				ON[vdvPanel,70]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Phase = <bool> true #'",1)) : 
				{
				SEND_STRING dvDebug,"'Phase State Invert Received from Rossini'"
				ON[vdvPanel,71]
				}
			}
		SELECT // Mute States 143 & 26
			{
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Mute = <bool> true #'",1))  : 
				{
				SEND_STRING dvDebug,"'Mute State Received from Rossini'"
				ON[vdvPanel,143]
				}
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Mute = <bool> false #'",1)) : 
				{
				SEND_STRING dvDebug,"'UnMute State Received from Rossini'"
				OFF[vdvPanel,143]
				}
			}
		SELECT // Volume
			{
			ACTIVE(FIND_STRING(chrdCSResponseString,"'# Volume = <int> '",1))  : 
				{
				REMOVE_STRING(chrdCSResponseString,'# Volume = <int> ',1)
				SEND_STRING dvDebug,"'Volume Level Received from Rossini ',chrdCSResponseString"
				}
			}
		}
	}

///////////////////////////////////////////////////////////////////////////////
// Transports
// 1-8
BUTTON_EVENT[vdvPanel,iTransportButs] 
	{
	PUSH:
		{
		iFunc = BUTTON.INPUT.CHANNEL
		SEND_COMMAND vdvRossini,"'Transport-',ITOA(iFunc)"  	// iFunc = 1:Play 2:Stop 3:Pause 4:FF 5:FR 6:Next 7:Prev 8:Eject
		}
	}

BUTTON_EVENT[vdvPanel,9]
	{
	PUSH:
		{
		IF([vdvPanel,9]) SEND_COMMAND vdvRossini,"'Power-0'"
		ELSE             SEND_COMMAND vdvRossini,"'Power-1'"
		//SEND_COMMAND vdvRossini,"'Power-0'"
		}
	}

// 11-19
BUTTON_EVENT[vdvPanel,iNumberButs] 
	{
	PUSH:
		{
		iFunc = BUTTON.INPUT.CHANNEL
		SEND_COMMAND vdvRossini,"'Number-',ITOA(iFunc)"  	// iFunc = 10:0, 11:1 to 19:9
		}
	}

BUTTON_EVENT[vdvPanel,22]
	{
	PUSH:
		{
		// Next
		iFunc = 6
		SEND_COMMAND vdvRossini,"'Transport-',ITOA(iFunc)"  	// iFunc = 1:Play 2:Stop 3:Pause 4:FF 5:FR 6:Next 7:Prev 8:Eject
		}
	}

BUTTON_EVENT[vdvPanel,23]
	{
	PUSH:
		{
		// Prev
		iFunc = 7
		SEND_COMMAND vdvRossini,"'Transport-',ITOA(iFunc)"  	// iFunc = 1:Play 2:Stop 3:Pause 4:FF 5:FR 6:Next 7:Prev 8:Eject
		}
	}

BUTTON_EVENT[vdvPanel,26]
	{
	PUSH:
		{
		iMute = !iMute
		IF(iMute) 
			{
			SEND_COMMAND vdvRossini,"'Mute-1'"
			ON[vdvPanel,26]
			}
		ELSE 			
			{
			SEND_COMMAND vdvRossini,"'Mute-0'"
			OFF[vdvPanel,26]
			}
		}
	}

// 27 & 28
BUTTON_EVENT[vdvPanel,iPowerButs]
	{
	PUSH:
		{
		iPowerState = BUTTON.INPUT.CHANNEL
		SEND_STRING dvDebug,"'Panel Power Button Pressed - ',ITOA(iPowerState)"
		SWITCH (iPowerState)
			{
			CASE 27: 
				{
				SEND_COMMAND vdvRossini,"'Power-On'"
				ON[vdvPanel,27]
				}
			CASE 28: 
				{
				SEND_COMMAND vdvRossini,"'Power-Off'"
				ON[vdvPanel,28]
				}
			}
		}
	}

// 30-38
BUTTON_EVENT[vdvPanel,iInputButs]
	{
	PUSH:
		{
		iInputState = BUTTON.INPUT.CHANNEL-30
		SEND_STRING dvDebug,"'Panel Input Button Pressed - ',ITOA(iInputState)"
		SEND_COMMAND vdvRossini,"'Input-',ITOA(iInputState)"
		ON[vdvPanel,iInputState+30]
		}
	}

// 44
BUTTON_EVENT[vdvPanel,iHelpBut]
	{
	PUSH:
		{
		SEND_COMMAND vdvRossini,"'Help'"
		}
	}

// 45
BUTTON_EVENT[vdvPanel,iStatusBut]
	{
	PUSH:
		{
		SEND_COMMAND vdvRossini,"'Status'"
		}
	}

// Sync 50-54
BUTTON_EVENT[vdvPanel,iSyncButs]
	{
	PUSH:
		{
		iFunc = BUTTON.INPUT.CHANNEL-50
		SEND_COMMAND vdvRossini,"'Sync-',ITOA(iFunc)"
		ON[vdvPanel,iFunc+50]
		}
	}

// Gain 60:2V /61:6V
BUTTON_EVENT[vdvPanel,iGainButs]
	{
	PUSH:
		{
		iFunc = BUTTON.INPUT.CHANNEL-60
		SEND_COMMAND vdvRossini,"'Gain-',ITOA(iFunc)"
		ON[vdvPanel,iFunc+60]
		}
	}

// Phase 70:Normal /71:Invert
BUTTON_EVENT[vdvPanel,iPhaseButs]
	{
	PUSH:
		{
		iFunc = BUTTON.INPUT.CHANNEL-70
		SEND_COMMAND vdvRossini,"'Phase-',ITOA(iFunc)"
		ON[vdvPanel,iFunc+70]
		}
	}

// Filter
BUTTON_EVENT[vdvPanel,iFilterButs]
	{
	PUSH:
		{
		iFunc = BUTTON.INPUT.CHANNEL-80
		SEND_COMMAND vdvRossini,"'Filter-',ITOA(iFunc)"
		ON[vdvPanel,iFunc+80]
		}
	}


// Volume
BUTTON_EVENT[vdvPanel,iVolButs]
	{
	PUSH:
		{
		iFunc = BUTTON.INPUT.CHANNEL
		SWITCH (iFunc)
			{
			CASE 141 : 
				{
				iVolumeLevel ++ // -80 to 0 - 0 = Loudest
				IF(iVolumeLevel > 80) iVolumeLevel = 80
				chrVolumeLevel = "'-',ITOA(80-iVolumeLevel)"
				SEND_STRING dvDebug,"'Volume-',ITOA(iVolumeLevel),' ASCII:',chrVolumeLevel"
				SEND_COMMAND vdvRossini,"'Volume-',chrVolumeLevel"
				SEND_LEVEL vdvPanel,1,iVolumeLevel
				}
			CASE 142 : 
				{
				iVolumeLevel -- // -80 to 0 - -80 = Mute
				IF(iVolumeLevel > 80) iVolumeLevel = 0
				chrVolumeLevel = "'-',ITOA(80-iVolumeLevel)"
				SEND_STRING dvDebug,"'Volume-',ITOA(iVolumeLevel),' ASCII:',chrVolumeLevel"
				SEND_COMMAND vdvRossini,"'Volume-',chrVolumeLevel"
				SEND_LEVEL vdvPanel,1,iVolumeLevel
				}
			CASE 143 : 
				{
				SEND_STRING dvDebug,"'Mute-',ITOA(iVolumeLevel),' ASCII:',chrVolumeLevel"
				iMute = !iMute
				IF(iMute)
					{
					SEND_COMMAND vdvRossini,"'Volume--80'"
					SEND_LEVEL vdvPanel,1,0
					}
				ELSE
					{
					SEND_COMMAND vdvRossini,"'Volume-',chrVolumeLevel"
					SEND_LEVEL vdvPanel,1,iVolumeLevel
					}
				}
			}
		}
	HOLD[3,REPEAT]:
		{
		SWITCH (iFunc)
			{
			CASE 141 : 
				{
				iVolumeLevel ++ // -80 to 0 - 0 = Loudest
				IF(iVolumeLevel > 80) iVolumeLevel = 80
				chrVolumeLevel = "'-',ITOA(80-iVolumeLevel)"
				SEND_STRING dvDebug,"'Volume-',ITOA(iVolumeLevel),' ASCII:',chrVolumeLevel"
				SEND_COMMAND vdvRossini,"'Volume-',chrVolumeLevel"
				SEND_LEVEL vdvPanel,1,iVolumeLevel
				}
			CASE 142 : 
				{
				iVolumeLevel -- // -80 to 0 - -80 = Mute
				IF(iVolumeLevel > 80) iVolumeLevel = 0
				chrVolumeLevel = "'-',ITOA(80-iVolumeLevel)"
				SEND_STRING dvDebug,"'Volume-',ITOA(iVolumeLevel),' ASCII:',chrVolumeLevel"
				SEND_COMMAND vdvRossini,"'Volume-',chrVolumeLevel"
				SEND_LEVEL vdvPanel,1,iVolumeLevel
				}
			}
		}
	}

// Balance
BUTTON_EVENT[vdvPanel,iBalButs]
	{
	PUSH:
		{
		iFunc = BUTTON.INPUT.CHANNEL
		SWITCH (iFunc)
			{
			CASE 147 : // Left
				{
				iBalance ++
				IF(iBalance > 13) iBalance = 13
				IF(iBalance < 7) chrBalance = TYPE_CAST("'-',ITOA(13-iBalance),'.0'")
				IF(iBalance = 7) chrBalance = TYPE_CAST("'0.0'")
				IF(iBalance > 7) chrBalance = TYPE_CAST("ITOA(iBalance),'.0'")
				SEND_LEVEL vdvPanel,2,iBalance
				}
			CASE 148 : // Right
				{
				iBalance --
				IF(iBalance > 13) iBalance = 0
				IF(iBalance < 7) chrBalance = TYPE_CAST("'-',ITOA(13-iBalance),'.0'")
				IF(iBalance = 7) chrBalance = TYPE_CAST("'0.0'")
				IF(iBalance > 7) chrBalance = TYPE_CAST("ITOA(iBalance),'.0'")
				SEND_LEVEL vdvPanel,2,iBalance
				}
			}
		}
	}

///////////////////////////////////////////////////////////////////////////////
// Online Status
CHANNEL_EVENT[vdvRossini,255]
	{
	ON:  
		{
		idCSRossininState = 1
		ON[vdvPanel,254]
		}
	OFF: 
		{
		idCSRossininState = 0
		OFF[vdvPanel,254]
		}
	}

(*****************************************************************)
(*                                                               *)
(*                      !!!! WARNING !!!!                        *)
(*                                                               *)
(* Due to differences in the underlying architecture of the      *)
(* X-Series masters, changing variables in the DEFINE_PROGRAM    *)
(* section of code can negatively impact program performance.    *)
(*                                                               *)
(* See Differences in DEFINE_PROGRAM Program Execution section *)
(* of the NX-Series Controllers WebConsole & Programming Guide   *)
(* for additional and alternate coding methodologies.            *)
(*****************************************************************)

DEFINE_PROGRAM

(*****************************************************************)
(*                       END OF PROGRAM                          *)
(*                                                               *)
(*         !!!  DO NOT PUT ANY CODE BELOW THIS COMMENT  !!!      *)
(*                                                               *)
(*****************************************************************)


